==> qcad-3.15.5.3.tgz: lib/qcad/scripts/View/ts/View_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Form</name>
    <message>
        <source>View Name</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wyświetl nazwę</translation>
    </message>
    <message>
        <source>View Name:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wyświetl nazwę:</translation>
    </message>
</context>
<context>
    <name>View</name>
    <message>
        <location filename="../View.js" line="+64"/>
        <source>View Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show view tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;View</source>
        <translatorcomment>--exact match--
--file: linguist_pl.ts--
&amp;Widok
&amp;Podgląd wydruku</translatorcomment>
        <translation type="unfinished">&amp;Widok</translation>
    </message>
</context>
<context>
    <name>ViewDialog</name>
    <message>
        <source>View Data</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Widok danych</translation>
    </message>
    <message>
        <source>Enter View Data</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wpisz widoku danych</translation>
    </message>
    <message>
        <source>Edit View Data</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Edytuj Wyświetl dane</translation>
    </message>
    <message>
        <source>Enter the name for the new view.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wprowadź nazwę nowego widoku.</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/View/ts/View_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Form</name>
    <message>
        <source>View Name</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wyświetl nazwę</translation>
    </message>
    <message>
        <source>View Name:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wyświetl nazwę:</translation>
    </message>
</context>
<context>
    <name>View</name>
    <message>
        <location filename="../View.js" line="+64"/>
        <source>View Tools</source>
        <translation>Narzędzia widoku</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show view tools</source>
        <translation>Wyświetla narzędzia widoku</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;View</source>
        <translatorcomment>--exact match--
--file: linguist_pl.ts--
&amp;Widok
&amp;Podgląd wydruku</translatorcomment>
        <translation>&amp;Widok</translation>
    </message>
</context>
<context>
    <name>ViewDialog</name>
    <message>
        <source>View Data</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Widok danych</translation>
    </message>
    <message>
        <source>Enter View Data</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wpisz widoku danych</translation>
    </message>
    <message>
        <source>Edit View Data</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Edytuj Wyświetl dane</translation>
    </message>
    <message>
        <source>Enter the name for the new view.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wprowadź nazwę nowego widoku.</translation>
    </message>
</context>
</TS>
